==> jc-1.4.0.tar.gz: java/security/SecureRandomSpi.h <==
// public abstract class java.security.SecureRandomSpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 254ca156f086a0ef java_security_SecureRandomSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_SecureRandomSpi_H_
#define _JC_java_security_SecureRandomSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_security_SecureRandomSpi$sub_refs	_jc_java_security_SecureRandomSpi$sub_refs;
typedef struct _jc_java_security_SecureRandomSpi$sub_nonrefs	_jc_java_security_SecureRandomSpi$sub_nonrefs;
typedef struct _jc_java_security_SecureRandomSpi$refs	_jc_java_security_SecureRandomSpi$refs;
typedef struct _jc_java_security_SecureRandomSpi$nonrefs	_jc_java_security_SecureRandomSpi$nonrefs;
typedef struct _jc_java_security_SecureRandomSpi$object	_jc_java_security_SecureRandomSpi$object;

typedef struct _jc_java_security_SecureRandomSpi$fields_struct	_jc_java_security_SecureRandomSpi$fields_struct;
typedef const struct _jc_java_security_SecureRandomSpi$vmethods	_jc_java_security_SecureRandomSpi$vmethods;
typedef const struct _jc_java_security_SecureRandomSpi$vtable	_jc_java_security_SecureRandomSpi$vtable;
typedef const struct _jc_java_security_SecureRandomSpi$vtype	_jc_java_security_SecureRandomSpi$vtype;

// Class fields structure
struct _jc_java_security_SecureRandomSpi$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_SecureRandomSpi$fields_struct _jc_java_security_SecureRandomSpi$class_fields;

// Constructors
extern void _jc_java_security_SecureRandomSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_SecureRandomSpi$object *);

// Virtual methods
extern _jc_byte_array *_jc_java_security_SecureRandomSpi$method$engineGenerateSeed$3f2678c95ef54b9d(_jc_env *, struct _jc_java_security_SecureRandomSpi$object *, jint);
extern void _jc_java_security_SecureRandomSpi$method$engineNextBytes$41b3d85f207b40da(_jc_env *, struct _jc_java_security_SecureRandomSpi$object *, struct _jc_byte_array *);
extern void _jc_java_security_SecureRandomSpi$method$engineSetSeed$d5670365ecc71f53(_jc_env *, struct _jc_java_security_SecureRandomSpi$object *, struct _jc_byte_array *);

// Virtual method descriptors
extern _jc_method _jc_java_security_SecureRandomSpi$method_info$engineGenerateSeed$3f2678c95ef54b9d;
extern _jc_method _jc_java_security_SecureRandomSpi$method_info$engineNextBytes$41b3d85f207b40da;
extern _jc_method _jc_java_security_SecureRandomSpi$method_info$engineSetSeed$d5670365ecc71f53;

// Virtual methods structure
struct _jc_java_security_SecureRandomSpi$vmethods {
	_jc_byte_array	*(*engineGenerateSeed$3f2678c95ef54b9d)(_jc_env *, struct _jc_java_security_SecureRandomSpi$object *, jint);
	void	(*engineNextBytes$41b3d85f207b40da)(_jc_env *, struct _jc_java_security_SecureRandomSpi$object *, struct _jc_byte_array *);
	void	(*engineSetSeed$d5670365ecc71f53)(_jc_env *, struct _jc_java_security_SecureRandomSpi$object *, struct _jc_byte_array *);
};

// Vtable
struct _jc_java_security_SecureRandomSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_SecureRandomSpi$vmethods	java_security_SecureRandomSpi;
};

// Vtype
struct _jc_java_security_SecureRandomSpi$vtype {
	_jc_type			type;
	_jc_java_security_SecureRandomSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_SecureRandomSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_SecureRandomSpi$refs {
    _jc_java_security_SecureRandomSpi$sub_refs	java_security_SecureRandomSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_SecureRandomSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_SecureRandomSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_SecureRandomSpi$sub_nonrefs	java_security_SecureRandomSpi;
};

// Object instance structure
struct _jc_java_security_SecureRandomSpi$object {
	_jc_java_security_SecureRandomSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_SecureRandomSpi$vtype	*vtype;
	_jc_java_security_SecureRandomSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_SecureRandomSpi$vtype _jc_java_security_SecureRandomSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_SecureRandomSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_SecureRandomSpi$class_object;

#endif	/* _JC_java_security_SecureRandomSpi_H_ */

==> jc-1.4.6.tar.gz: java/security/SecureRandomSpi.h <==
// public abstract class java.security.SecureRandomSpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 254ca156f086a0ef java_security_SecureRandomSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_SecureRandomSpi_H_
#define _JC_java_security_SecureRandomSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_security_SecureRandomSpi$sub_refs	_jc_java_security_SecureRandomSpi$sub_refs;
typedef struct _jc_java_security_SecureRandomSpi$sub_nonrefs	_jc_java_security_SecureRandomSpi$sub_nonrefs;
typedef struct _jc_java_security_SecureRandomSpi$refs	_jc_java_security_SecureRandomSpi$refs;
typedef struct _jc_java_security_SecureRandomSpi$nonrefs	_jc_java_security_SecureRandomSpi$nonrefs;
typedef struct _jc_java_security_SecureRandomSpi$object	_jc_java_security_SecureRandomSpi$object;

typedef struct _jc_java_security_SecureRandomSpi$fields_struct	_jc_java_security_SecureRandomSpi$fields_struct;
typedef const struct _jc_java_security_SecureRandomSpi$vmethods	_jc_java_security_SecureRandomSpi$vmethods;
typedef const struct _jc_java_security_SecureRandomSpi$vtable	_jc_java_security_SecureRandomSpi$vtable;
typedef const struct _jc_java_security_SecureRandomSpi$vtype	_jc_java_security_SecureRandomSpi$vtype;

// Class fields structure
struct _jc_java_security_SecureRandomSpi$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_SecureRandomSpi$fields_struct _jc_java_security_SecureRandomSpi$class_fields;

// Constructors
extern void _jc_java_security_SecureRandomSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_SecureRandomSpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_java_security_SecureRandomSpi$method$engineGenerateSeed$3f2678c95ef54b9d(_jc_env *, struct _jc_java_security_SecureRandomSpi$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_security_SecureRandomSpi$method$engineNextBytes$41b3d85f207b40da(_jc_env *, struct _jc_java_security_SecureRandomSpi$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_java_security_SecureRandomSpi$method$engineSetSeed$d5670365ecc71f53(_jc_env *, struct _jc_java_security_SecureRandomSpi$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_SecureRandomSpi$method_info$engineGenerateSeed$3f2678c95ef54b9d;
extern _jc_method _jc_java_security_SecureRandomSpi$method_info$engineNextBytes$41b3d85f207b40da;
extern _jc_method _jc_java_security_SecureRandomSpi$method_info$engineSetSeed$d5670365ecc71f53;

// Virtual methods structure
struct _jc_java_security_SecureRandomSpi$vmethods {
	_jc_byte_array	*(*engineGenerateSeed$3f2678c95ef54b9d)(_jc_env *, struct _jc_java_security_SecureRandomSpi$object *, jint) _JC_JCNI_ATTR;
	void	(*engineNextBytes$41b3d85f207b40da)(_jc_env *, struct _jc_java_security_SecureRandomSpi$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	void	(*engineSetSeed$d5670365ecc71f53)(_jc_env *, struct _jc_java_security_SecureRandomSpi$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_SecureRandomSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_SecureRandomSpi$vmethods	java_security_SecureRandomSpi;
};

// Vtype
struct _jc_java_security_SecureRandomSpi$vtype {
	_jc_type			type;
	_jc_java_security_SecureRandomSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_SecureRandomSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_SecureRandomSpi$refs {
    _jc_java_security_SecureRandomSpi$sub_refs	java_security_SecureRandomSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_SecureRandomSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_SecureRandomSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_SecureRandomSpi$sub_nonrefs	java_security_SecureRandomSpi;
};

// Object instance structure
struct _jc_java_security_SecureRandomSpi$object {
	_jc_java_security_SecureRandomSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_SecureRandomSpi$vtype	*vtype;
	_jc_java_security_SecureRandomSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_SecureRandomSpi$vtype _jc_java_security_SecureRandomSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_SecureRandomSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_SecureRandomSpi$class_object;

#endif	/* _JC_java_security_SecureRandomSpi_H_ */
